@@ -23,11 +23,12 @@ import (
 	"time"
 
 	bmoapis "github.com/metal3-io/baremetal-operator/pkg/apis"
-	"github.com/metal3-io/cluster-api-provider-baremetal/pkg/apis"
-	"github.com/metal3-io/cluster-api-provider-baremetal/pkg/cloud/baremetal/actuators/machine"
-	"github.com/metal3-io/cluster-api-provider-baremetal/pkg/manager/wrapper"
-	clusterapis "github.com/openshift/cluster-api/pkg/apis"
-	capimachine "github.com/openshift/cluster-api/pkg/controller/machine"
+	"github.com/openshift/cluster-api-provider-baremetal/pkg/apis"
+	"github.com/openshift/cluster-api-provider-baremetal/pkg/cloud/baremetal/actuators/machine"
+	"github.com/openshift/cluster-api-provider-baremetal/pkg/controller"
+	"github.com/openshift/cluster-api-provider-baremetal/pkg/manager/wrapper"
+	machinev1beta1 "github.com/openshift/machine-api-operator/pkg/apis/machine/v1beta1"
+	maomachine "github.com/openshift/machine-api-operator/pkg/controller/machine"
 	"k8s.io/apimachinery/pkg/runtime/schema"
 	"k8s.io/client-go/discovery"
 	"k8s.io/client-go/rest"
@@ -43,6 +44,7 @@ func main() {
 
 	watchNamespace := flag.String("namespace", "", "Namespace that the controller watches to reconcile machine-api objects. If unspecified, the controller watches for machine-api objects across all namespaces.")
 	metricsAddr := flag.String("metrics-addr", ":8080", "The address the metric endpoint binds to.")
+	enableLeaderElection := flag.Bool("enable-leader-election", false, "Enable leader election for controller manager. Enabling this will ensure there is only one active controller manager.")
 	flag.Parse()
 
 	log := logf.Log.WithName("baremetal-controller-manager")
@@ -63,6 +65,8 @@ func main() {
 	// Setup a Manager
 	opts := manager.Options{
 		MetricsBindAddress: *metricsAddr,
+		LeaderElection:     *enableLeaderElection,
+		LeaderElectionID:   "controller-leader-election-capbm",
 	}
 	if *watchNamespace != "" {
 		opts.Namespace = *watchNamespace
@@ -86,7 +90,7 @@ func main() {
 		panic(err)
 	}
 
-	if err := clusterapis.AddToScheme(mgr.GetScheme()); err != nil {
+	if err := machinev1beta1.AddToScheme(mgr.GetScheme()); err != nil {
 		panic(err)
 	}
 
@@ -95,7 +99,12 @@ func main() {
 	}
 
 	// the manager wrapper will add an extra Watch to the controller
-	capimachine.AddWithActuator(wrapper.New(mgr), machineActuator)
+	maomachine.AddWithActuator(wrapper.New(mgr), machineActuator)
+
+	if err := controller.AddToManager(mgr); err != nil {
+		log.Error(err, "Failed to add controller to manager")
+		os.Exit(1)
+	}
 
 	if err := mgr.Start(signals.SetupSignalHandler()); err != nil {
 		entryLog.Error(err, "unable to run manager")
